BufferedFileIoFactory

Type Alias BufferedFileIoFactory 

pub type BufferedFileIoFactory = TypedIoWrite<BufWriter<File>>;
A pre-configured factory for logging to a BufWriter<File>.

Performance Tip: This is significantly faster than a raw File for high-frequency logging because it reduces the number of expensive System Calls by batching writes in memory.

Aliased Type

pub struct BufferedFileIoFactory { /* private fields */ }