pub type BoxedIoFactory = TypedIoWrite<Box<dyn Write + Send + Sync>>;Expand description
A pre-configured factory for logging to a boxed Write trait object.
Useful for plugin systems or when the underlying writer type is erased.
Aliased Type
pub struct BoxedIoFactory { /* private fields */ }